@@ -4,14 +4,14 @@ C dependence model with random effects
 C dimension of x and vectors assume the maximum values
 CCCCC
 
-      DOUBLE PRECISION FUNCTION f1var(v,i)
+      DOUBLE PRECISION FUNCTION f1var(v)
       DOUBLE PRECISION logL,prob,beta1,bt1,lpsi1,x1,
      *theta1,work1,omega1,v
-      INTEGER m, mpar, y1,i
+      INTEGER m, mpar, y1
       DIMENSION x1(5000,10),theta1(5000),
      *work1(5000),y1(5000),prob(5000),beta1(10),bt1(10)
 
-      COMMON/param/x1,theta1,work1,
+      COMMON/param1/x1,theta1,work1,
      *y1,beta1,bt1,m,mpar,omega1,lpsi1
 
       beta1(1) = v +bt1(1)
